@@ -1,87 +1,200 @@
+use 5.008;    # utf8
 use strict;
 use warnings;
+use utf8;
 
 package Path::ScanINC;
-BEGIN {
-  $Path::ScanINC::AUTHORITY = 'cpan:KENTNL';
-}
-{
-  $Path::ScanINC::VERSION = '0.011';
-}
-
+$Path::ScanINC::VERSION = '0.020';
 # ABSTRACT: Emulate Perls internal handling of @INC.
+
+our $AUTHORITY = 'cpan:KENTNL'; # AUTHORITY
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
 
 
 # Sub Lazy-Aliases
 use subs 'inc';
 use Class::Tiny qw(inc immutable);
+use Try::Tiny qw( try catch );
+use Scalar::Util qw( blessed reftype );
+use Carp qw( croak );
+use Path::Tiny qw( path );
 
-## no critic (ProhibitSubroutinePrototypes)
-sub __try(&;@)   { require Try::Tiny;    goto \&Try::Tiny::try; }
-sub __catch(&;@) { require Try::Tiny;    goto \&Try::Tiny::catch; }
-sub __blessed($) { require Scalar::Util; goto \&Scalar::Util::blessed; }
-sub __reftype($) { require Scalar::Util; goto \&Scalar::Util::reftype; }
-## use critic
-sub __pp    { require Data::Dump; goto \&Data::Dump::pp; }
-sub __croak { require Carp;       goto \&Carp::croak; }
-sub __path  { require Path::Tiny; goto \&Path::Tiny::path; }
+## no critic (Bangs::ProhibitDebuggingModules)
+sub __pp { require Data::Dump; goto \&Data::Dump::pp; }
 ## no critic (RequireArgUnpacking)
 sub __croakf { require Carp; @_ = ( sprintf $_[0], splice @_, 1 ); goto \&Carp::croak; }
 ## use critic
 
 
 
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
 sub _bad_param {
-	my ( $obj, $name, $expected, $got ) = @_;
-	my $format =
-		qq[Initialization parameter '%s' to \$object->new( ) ( %s->new() ) expects %s.\n] . qq[\tYou gave \$object->new( %s => %s )];
-	return __croakf( $format, $name, __blessed($obj), $expected, $name, __pp($got) );
+  my ( $self, $name, $expected, $got ) = @_;
+  my $format =
+    qq[Initialization parameter '%s' to \$object->new( ) ( %s->new() ) expects %s.\n] . qq[\tYou gave \$object->new( %s => %s )];
+  return __croakf( $format, $name, blessed($self), $expected, $name, __pp($got) );
 }
 
 sub _fix_immutable {
-	my ($self) = @_;
-	if ( exists $self->{immutable} ) {
-		return $self->_bad_param( 'immutable', 'undef/a true value', $self->{immutable} ) if ref $self->{immutable};
-		$self->{immutable} = !!( $self->{immutable} );
-	}
-	return;
+  my ($self) = @_;
+  if ( exists $self->{immutable} ) {
+    return $self->_bad_param( 'immutable', 'undef/a true value', $self->{immutable} ) if ref $self->{immutable};
+    $self->{immutable} = !!( $self->{immutable} );
+  }
+  return;
 }
 
 sub _fix_inc {
-	my ($self) = @_;
-	if ( exists $self->{inc} ) {
-		return $self->_bad_param( 'inc', 'an array-reference', $self->{inc} )
-			if not __try { my $i = $self->{inc}->[0]; 1 } __catch { undef };
-	}
-	if ( $self->immutable ) {
-		if ( exists $self->{inc} ) {
-			$self->{inc} = [ @{ $self->{inc} } ];
-		}
-		else {
-			$self->{inc} = [@INC];
-		}
-	}
-	return;
+  my ($self) = @_;
+  if ( exists $self->{inc} ) {
+    return $self->_bad_param( 'inc', 'an array-reference', $self->{inc} )
+      if not try { scalar $self->{inc}->[0]; 1 } catch { undef };
+  }
+  if ( $self->immutable ) {
+    if ( exists $self->{inc} ) {
+      $self->{inc} = [ @{ $self->{inc} } ];
+    }
+    else {
+      $self->{inc} = [@INC];
+    }
+  }
+  return;
 }
 
 
+
+
+
+
+
+
+
 sub BUILD {
-	my ( $self, $args ) = @_;
-	$self->_fix_immutable;
-	$self->_fix_inc;
-    return;
+  my ( $self, ) = @_;
+  $self->_fix_immutable;
+  $self->_fix_inc;
+  return;
 }
 
 
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
 sub inc {
-	my ( $obj, @args ) = @_;
-	return @INC if ( not exists $obj->{inc} );
-	return @{ $obj->{inc} };
+  my ( $self, ) = @_;
+  return @INC if ( not exists $self->{inc} );
+  return @{ $self->{inc} };
 }
 
 sub _pm_inc_path {
-	my ( $self, @path_parts ) = @_;
-	return join q[/], @path_parts;
+  my ( undef, @path_parts ) = @_;
+  return join q[/], @path_parts;
 }
 
 # This method deals with the fact there are refs in @INC, and they have special magic behaviour.
@@ -96,120 +209,215 @@ sub _pm_inc_path {
 #
 
 sub _ref_expand {
-	my ( $self, $ref, @query ) = @_;
+  my ( $self, $ref, @query ) = @_;
 
-	# See perldoc perlfunc / require
-	if ( __blessed($ref) ) {
-		my (@result) = $ref->INC( $self->_pm_inc_path(@query) );
-		if ( not @result ) {
-			return [ undef, ];
-		}
-		return [ 1, @result ];
-	}
-	if ( __reftype($ref) eq 'CODE' ) {
-		my (@result) = $ref->( $ref, $self->_pm_inc_path(@query) );
-		if ( not @result ) {
-			return [ undef, ];
-		}
-		return [ 1, @result ];
-	}
-	if ( __reftype($ref) eq 'ARRAY' ) {
-		my $code = $ref->[0];
-		my (@result) = $code->( $ref, $self->_pm_inc_path(@query) );
-		if ( not @result ) {
-			return [ undef, ];
-		}
-		return [ 1, @result ];
-	}
-	## no critic (RequireInterpolationOfMetachars)
+  # See perldoc perlfunc / require
+  if ( blessed($ref) ) {
+    my (@result) = $ref->INC( $self->_pm_inc_path(@query) );
+    if ( not @result ) {
+      return [ undef, ];
+    }
+    return [ 1, @result ];
+  }
+  if ( 'CODE' eq reftype($ref) ) {
+    my (@result) = $ref->( $ref, $self->_pm_inc_path(@query) );
+    if ( not @result ) {
+      return [ undef, ];
+    }
+    return [ 1, @result ];
+  }
+  if ( 'ARRAY' eq reftype($ref) ) {
+    my $code = $ref->[0];
+    my (@result) = $code->( $ref, $self->_pm_inc_path(@query) );
+    if ( not @result ) {
+      return [ undef, ];
+    }
+    return [ 1, @result ];
+  }
+  ## no critic (RequireInterpolationOfMetachars)
 
-	__croakf( 'Unknown type of ref in @INC not supported: %s', __reftype($ref) );
-	return [ undef, ];
+  __croakf( 'Unknown type of ref in @INC not supported: %s', reftype($ref) );
+  return [ undef, ];
 }
 
 
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
 sub first_file {
-	my ( $self, @args ) = @_;
+  my ( $self, @args ) = @_;
 
-	for my $path ( $self->inc ) {
-		if ( ref $path ) {
-			my $result = $self->_ref_expand( $path, @args );
-			if ( $result->[0] ) {
-				shift @{$result};
-				return $result;
-			}
-			next;
-		}
-		my $fullpath = __path($path)->child(@args);
-		if ( -e $fullpath and -f $fullpath ) {
-			return $fullpath;
-		}
-	}
-	return;
+  for my $path ( $self->inc ) {
+    if ( ref $path ) {
+      my $result = $self->_ref_expand( $path, @args );
+      if ( $result->[0] ) {
+        shift @{$result};
+        return $result;
+      }
+      next;
+    }
+    my $fullpath = path($path)->child(@args);
+    if ( -e $fullpath and not -d $fullpath ) {
+      return $fullpath;
+    }
+  }
+  return;
 }
 
 
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
 sub all_files {
-	my ( $self, @args ) = @_;
+  my ( $self, @args ) = @_;
 
-	my @out;
-	for my $path ( $self->inc ) {
-		if ( ref $path ) {
-			my $result = $self->_ref_expand( $path, @args );
-			if ( $result->[0] ) {
-				shift @{$result};
-				push @out, $result;
-			}
-			next;
-		}
-		my $fullpath = __path($path)->child(@args);
-		if ( -e $fullpath and -f $fullpath ) {
-			push @out, $fullpath;
-		}
-	}
-	return @out;
+  my @out;
+  for my $path ( $self->inc ) {
+    if ( ref $path ) {
+      my $result = $self->_ref_expand( $path, @args );
+      if ( $result->[0] ) {
+        shift @{$result};
+        push @out, $result;
+      }
+      next;
+    }
+    my $fullpath = path($path)->child(@args);
+    if ( -e $fullpath and not -d $fullpath ) {
+      push @out, $fullpath;
+    }
+  }
+  return @out;
 }
 
 
+
+
+
+
+
 sub first_dir {
-	my ( $self, @args ) = @_;
+  my ( $self, @args ) = @_;
 
-	for my $path ( $self->inc ) {
-		if ( ref $path ) {
-			my $result = $self->_ref_expand( $path, @args );
-			if ( $result->[0] ) {
-				shift @{$result};
-				return $result;
-			}
-			next;
-		}
-		my $fullpath = __path($path)->child(@args);
-		if ( -e $fullpath and -d $fullpath ) {
-			return $fullpath;
-		}
-	}
-	return;
+  for my $path ( $self->inc ) {
+    if ( ref $path ) {
+      my $result = $self->_ref_expand( $path, @args );
+      if ( $result->[0] ) {
+        shift @{$result};
+        return $result;
+      }
+      next;
+    }
+    my $fullpath = path($path)->child(@args);
+    if ( -e $fullpath and -d $fullpath ) {
+      return $fullpath;
+    }
+  }
+  return;
 }
 
 
+
+
+
+
+
 sub all_dirs {
-	my ( $self, @args ) = @_;
-	my @out;
-	for my $path ( $self->inc ) {
-		if ( ref $path ) {
-			my $result = $self->_ref_expand( $path, @args );
-			if ( $result->[0] ) {
-				shift @{$result};
-				push @out, $result;
-			}
-			next;
-		}
-		my $fullpath = __path($path)->child(@args);
-		if ( -e $fullpath and -d $fullpath ) {
-			push @out, $fullpath;
-		}
-	}
-	return @out;
+  my ( $self, @args ) = @_;
+  my @out;
+  for my $path ( $self->inc ) {
+    if ( ref $path ) {
+      my $result = $self->_ref_expand( $path, @args );
+      if ( $result->[0] ) {
+        shift @{$result};
+        push @out, $result;
+      }
+      next;
+    }
+    my $fullpath = path($path)->child(@args);
+    if ( -e $fullpath and -d $fullpath ) {
+      push @out, $fullpath;
+    }
+  }
+  return @out;
 }
 
 1;
@@ -226,12 +434,12 @@ Path::ScanINC - Emulate Perls internal handling of @INC.
 
 =head1 VERSION
 
-version 0.011
+version 0.020
 
 =head1 SYNOPSIS
 
 The Aim of this module is to fully implement everything Perl does with C<@INC>, to be feature compatible with it, including
-the behaviour with regard to C<sub refs> in C<@INC>.
+the behavior with regard to C<sub refs> in C<@INC>.
 
 	use Path::ScanINC;
 
@@ -358,7 +566,7 @@ of strings, not slash-separated strings.
 	$inc->first_file('MooseX' , 'Declare.pm')  # Good
 	$inc->first_file('MooseX/Declare.pm')      # Bad.
 
-This is for several reasons, all of which can be summarised as "Windows".
+This is for several reasons, all of which can be summarized as "Windows".
 
 =over 4
 
@@ -435,7 +643,7 @@ Kent Fredric <kentnl@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Kent Fredric <kentnl@cpan.org>.
+This software is copyright (c) 2014 by Kent Fredric <kentnl@cpan.org>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
